==> jena-arq-2.10.1-sources.jar: com/hp/hpl/jena/sparql/expr/E_Equals.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hp.hpl.jena.sparql.expr;

public class E_Equals extends ExprFunction2
{
    private static final String printName = "eq" ;
    private static final String symbol = "=" ;    

    public E_Equals(Expr left, Expr right)
    {
        super(left, right, printName, symbol) ;
    }
    
    @Override
    public NodeValue eval(NodeValue x, NodeValue y)
    {
        // Note: notSameValueAs means "known to be different"
        // sameValueAs means "know to be the same value"
        // so they are not opposites

        boolean b = NodeValue.sameAs(x, y) ;
        return NodeValue.booleanReturn(b) ;
    }
    
    @Override
    public Expr copy(Expr e1, Expr e2) {  return new E_Equals(e1 , e2 ) ; }
}

==> jena-arq-2.13.0-sources.jar: com/hp/hpl/jena/sparql/expr/E_Equals.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hp.hpl.jena.sparql.expr;

import com.hp.hpl.jena.sparql.sse.Tags;

public class E_Equals extends ExprFunction2
{
    private static final String functionName = Tags.tagEQ ;
    private static final String symbol = Tags.symEQ ;    

    public E_Equals(Expr left, Expr right)
    {
        super(left, right, functionName, symbol) ;
    }
    
    @Override
    public NodeValue eval(NodeValue x, NodeValue y)
    {
        // Note: notSameValueAs means "known to be different"
        // sameValueAs means "know to be the same value"
        // so they are not opposites

        boolean b = NodeValue.sameAs(x, y) ;
        return NodeValue.booleanReturn(b) ;
    }
    
    @Override
    public Expr copy(Expr e1, Expr e2) {  return new E_Equals(e1 , e2 ) ; }
}
